# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import SyncClientWrapper
from .raw_client import RawPastClient
from .forecast.client import ForecastClient
from ...core.client_wrapper import AsyncClientWrapper
from .raw_client import AsyncRawPastClient
from .forecast.client import AsyncForecastClient


class PastClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawPastClient(client_wrapper=client_wrapper)
        self.forecast = ForecastClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawPastClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawPastClient
        """
        return self._raw_client


class AsyncPastClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawPastClient(client_wrapper=client_wrapper)
        self.forecast = AsyncForecastClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawPastClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawPastClient
        """
        return self._raw_client
