# This file was auto-generated by Fern from our API Definition.

import typing
from .base_model import BaseModel

FeatureProperties = typing.Union[typing.Dict[str, typing.Optional[typing.Any]], BaseModel]
