# This file was auto-generated by Fern from our API Definition.

import typing
from .position_2_d import Position2D
from .position_3_d import Position3D

MultiPointCoordinatesItem = typing.Union[Position2D, Position3D]
