# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .multi_line_string_coordinates_item_item import MultiLineStringCoordinatesItemItem
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class MultiLineString(UniversalBaseModel):
    """
    MultiLineString Model
    """

    bbox: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    coordinates: typing.List[typing.List[MultiLineStringCoordinatesItemItem]]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
