# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .geo_location import GeoLocation
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class CycloneForecastResponse(UniversalBaseModel):
    storm_id: str
    storm_name: str
    type: str
    category: int
    position: GeoLocation
    forecast_time: dt.datetime
    forecast_source_info: str
    last_updated: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
