# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
from .raw_client import RawWeatherClient
from .forecast.client import ForecastClient
from .experimental.client import ExperimentalClient
from .past.client import PastClient
from ..core.client_wrapper import AsyncClientWrapper
from .raw_client import AsyncRawWeatherClient
from .forecast.client import AsyncForecastClient
from .experimental.client import AsyncExperimentalClient
from .past.client import AsyncPastClient


class WeatherClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawWeatherClient(client_wrapper=client_wrapper)
        self.forecast = ForecastClient(client_wrapper=client_wrapper)

        self.experimental = ExperimentalClient(client_wrapper=client_wrapper)

        self.past = PastClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawWeatherClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawWeatherClient
        """
        return self._raw_client


class AsyncWeatherClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawWeatherClient(client_wrapper=client_wrapper)
        self.forecast = AsyncForecastClient(client_wrapper=client_wrapper)

        self.experimental = AsyncExperimentalClient(client_wrapper=client_wrapper)

        self.past = AsyncPastClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawWeatherClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawWeatherClient
        """
        return self._raw_client
